CppOptions class

Options that control how C++ code will be generated.

Constructors

CppOptions({String? headerIncludePath, String? namespace, Iterable<String>? copyrightHeader, String? headerOutPath})
Creates a CppOptions object
const

Properties

copyrightHeader → Iterable<String>?
A copyright header that will get prepended to generated code.
final
hashCode → int
The hash code for this object.
no setterinherited
headerIncludePath → String?
The path to the header that will get placed in the source filed (example: "foo.h").
final
headerOutPath → String?
The path to the output header file location.
final
namespace → String?
The namespace where the generated class will live.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

merge(CppOptions options) → CppOptions
Overrides any non-null parameters from options into this to make a new CppOptions.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object>
Converts a CppOptions to a Map representation where: x = CppOptions.fromMap(x.toMap()).
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, Object> map) → CppOptions
Creates a CppOptions from a Map representation where: x = CppOptions.fromMap(x.toMap()).