JavaOptions class

Options that control how Java code will be generated.

Constructors

JavaOptions({String? className, String? package, Iterable<String>? copyrightHeader, bool? useGeneratedAnnotation})
Creates a JavaOptions object
const

Properties

className → String?
The name of the class that will house all the generated classes.
final
copyrightHeader → Iterable<String>?
A copyright header that will get prepended to generated code.
final
hashCode → int
The hash code for this object.
no setterinherited
package → String?
The package where the generated class will live.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useGeneratedAnnotation → bool?
Determines if the javax.annotation.Generated is used in the output. This is false by default since that dependency isn't available in plugins by default .
final

Methods

merge(JavaOptions options) → JavaOptions
Overrides any non-null parameters from options into this to make a new JavaOptions.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object>
Converts a JavaOptions to a Map representation where: x = JavaOptions.fromMap(x.toMap()).
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, Object> map) → JavaOptions
Creates a JavaOptions from a Map representation where: x = JavaOptions.fromMap(x.toMap()).